/*
SRSourceWindowController.h

Author: Makoto Kinoshita

Copyright 2004 The Shiira Project. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted 
provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions 
  and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of 
  conditions and the following disclaimer in the documentation and/or other materials provided 
  with the distribution.

THIS SOFTWARE IS PROVIDED BY THE SHIIRA PROJECT ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE SHIIRA PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/

#import <Cocoa/Cocoa.h>
#import <WebKit/WebKit.h>
#import "SRError.h"

@interface SRSourceWindowController : NSWindowController
{
    WebDataSource*  _dataSource;
    DOMDocument*    _DOMDocument;
    
    IBOutlet id _disclosureBtn;
    IBOutlet id _disclosureLabel;
    IBOutlet id _headerKindPopup;
    
    IBOutlet id _splitView;
    IBOutlet id _HTTPHeadersTable;
    IBOutlet id _sourceTab;
    
    IBOutlet id _sourceTextView;    // WebSearchableTextView
    
    IBOutlet id _DOMOutlineView;
    IBOutlet id _DOMTreeController;
    IBOutlet id _DOMTextView;       // WebSearchableTextView
}

+ (SRSourceWindowController*)sourceWindowWithWebDataSource:(WebDataSource*)dataSource;

- (WebDataSource*)dataSource;
- (void)setDataSource:(WebDataSource*)dataSource;
- (NSString*)title;
- (NSURL*)URL;
- (NSTextView*)sourceTextView;
- (NSTextView*)DOMTextView;
- (NSTextView*)selectedTextView;

- (void)setSource:(NSString*)source;
- (void)setDOMSource:(NSString*)source;
- (NSAttributedString*)colorizedSourceOfString:(NSString*)source;

- (IBAction)disclosureBtnAction:(id)sender;
- (void)_doDisclosure:(BOOL)state;

- (void)selectHeaderKindAction:(id)sender;

@end


@interface SRSourceSplitView : NSSplitView
{
    float   _savedFirstViewHeight;
}
- (float)savedFirstViewHeight;
- (void)setSavedFirstViewHeight:(float)value;
- (float)firstViewHeight;
@end

